@@ -33,7 +33,8 @@ LearnerDensKDE = R6::R6Class("LearnerDensKDE",
         predict_types = "pdf",
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
         properties = "missings",
-        packages = "distr6"
+        packages = "distr6",
+        man = "mlr3proba::mlr_learners_dens.kde"
       )
     }
   ),
@@ -45,18 +46,19 @@ LearnerDensKDE = R6::R6Class("LearnerDensKDE",
         ShortName == self$param_set$values$kernel,
         ClassName)))$new()
       bw = ifelse(self$param_set$values$bandwidth == "silver",
-        0.9 * min(sd(task$truth()), IQR(task$truth(), na.rm = TRUE) / 1.349, na.rm = TRUE) * length(task$truth())^(-0.2),
+        0.9 * min(sd(task$truth()), IQR(task$truth(), na.rm = TRUE) / 1.349, na.rm = TRUE) *
+          length(task$truth())^-0.2,
         self$param_set$values$bandwidth)
 
-      pdf = function(x1) {} #nolint
+      pdf = function(x) {} #nolint
 
       body(pdf) = substitute({
-        if (length(x1) == 1) {
-          return(1 / (rows * bw) * sum(kernel$pdf((x1 - train) / bw)))
+        if (length(x) == 1) {
+          return(1 / (rows * bw) * sum(kernel$pdf((x - train) / bw)))
         } else {
-          x1 = matrix(x1, nrow = length(x1), ncol = rows)
-          train_mat = matrix(train, nrow = nrow(x1), ncol = rows, byrow = TRUE)
-          return(1 / (rows * bw) * colSums(apply((x1 - train_mat) / bw, 1, kernel$pdf)))
+          x = matrix(x, nrow = length(x), ncol = rows)
+          train_mat = matrix(train, nrow = nrow(x), ncol = rows, byrow = TRUE)
+          return(1 / (rows * bw) * colSums(apply((x - train_mat) / bw, 1, kernel$pdf)))
         }
       }, list(
         rows = task$nrow,
@@ -67,6 +69,7 @@ LearnerDensKDE = R6::R6Class("LearnerDensKDE",
       Distribution$new(
         name = paste(self$param_set$values$kernel, "KDE"),
         short_name = paste0(self$param_set$values$kernel, "_KDE"),
+        type = set6::Reals$new(),
         pdf = pdf)
     },
 
