@@ -9,7 +9,8 @@
 #'
 #' The standard error of the Logloss, L, is approximated via,
 #' \deqn{se(L) = sd(L)/\sqrt{N}}{se(L) = sd(L)/\sqrt N}
-#' where \eqn{N} are the number of observations in the test set, and \eqn{sd} is the standard deviation.
+#' where \eqn{N} are the number of observations in the test set, and \eqn{sd} is the standard
+#' deviation.
 #'
 #' Censored observations in the test set are ignored.
 #'
@@ -22,7 +23,9 @@ MeasureSurvLoglossSE = R6::R6Class("MeasureSurvLoglossSE",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function(eps = 1e-15) {
+      warning('MeasureSurvLoglossSE is now deprecated, use msr("surv.logloss", se = TRUE) instead.')
       super$initialize(eps, id = "surv.loglossSE")
+      self$man = "mlr3proba::mlr_measures_surv.loglossSE"
     }
   ),
 
