@@ -20,13 +20,16 @@ MeasureSurvUnoC = R6Class("MeasureSurvUnoC",
   public = list(
     #' @description Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
+      warning("This is now deprecated, use MeasureSurvCindex instead with `weight_meth = 'G/2'`.")
+
       super$initialize(
         id = "surv.unoC",
         range = 0:1,
         minimize = FALSE,
         packages = "survAUC",
         predict_type = "crank",
-        properties = c("na_score", "requires_task", "requires_train_set")
+        properties = c("na_score", "requires_task", "requires_train_set"),
+        man = "mlr3proba::mlr_measures_surv.unoC"
       )
     }
   ),
